# PassMan
<img src="assets/pill-2.0.0.svg">

PassMan is a super simple, Python-based **pass**word **man**agement console application. Data is managed using Peewee ORM and stored in a Sqlite3 database.

<img src="https://user-images.githubusercontent.com/15679739/41821414-35dbb9a2-7795-11e8-97f3-be07107a304f.gif">

### Dependencies
* Python3
  * Check version using `$ python --version`
  * <a href="https://www.python.org/downloads/release/python-365/">Installing or upgrading to Python3</a>
* <a href="http://docs.peewee-orm.com/en/latest/">PeeWee</a>
* <a href="https://www.sqlite.org/index.html">SQLite3</a>
* <a href="https://pypi.org/project/bcrypt/">Bcrypt</a>
* <a href="https://pypi.org/project/colorama/">Colorama</a> and <a href="https://pypi.org/project/termcolor/">Termcolor</a>
* <a href="https://pypi.org/project/pyperclip/">Pyperclip</a>

### Installation and Usage
```shell
$ # via pip
$ pip3 install mypassman
$ passman
```

**Author:**  
Sean Pierce Sumler

**License:**  
<a href="LICENSE">MIT</a>, use at your own risk

For questions and comments please <a href="https://github.com/seanpierce/passman/issues/new">raise an issue</a>. <a href="https://github.com/seanpierce/passman/compare">Pull requests</a> always welcome, too. Thanks!
